@@ -387,6 +387,9 @@ func mergeConfig(config *libconfig.Config, ctx *cli.Context) error {
 	if ctx.IsSet("infra-ctr-cpuset") {
 		config.InfraCtrCPUSet = ctx.String("infra-ctr-cpuset")
 	}
+	if ctx.IsSet("shared-cpuset") {
+		config.SharedCPUSet = ctx.String("shared-cpuset")
+	}
 	if ctx.IsSet("stats-collection-period") {
 		config.StatsCollectionPeriod = ctx.Int("stats-collection-period")
 	}
@@ -1093,6 +1096,12 @@ func getCrioFlags(defConf *libconfig.Config) []cli.Flag {
 			EnvVars: []string{"CONTAINER_INFRA_CTR_CPUSET"},
 			Value:   defConf.InfraCtrCPUSet,
 		},
+		&cli.StringFlag{
+			Name:    "shared-cpuset",
+			Usage:   "CPUs set that will be used for guaranteed containers that want access to shared cpus",
+			EnvVars: []string{"CONTAINER_SHARED_CPUSET"},
+			Value:   defConf.SharedCPUSet,
+		},
 		&cli.StringFlag{
 			Name:      "clean-shutdown-file",
 			Usage:     "Location for CRI-O to lay down the clean shutdown file. It indicates whether we've had time to sync changes to disk before shutting down. If not found, crio wipe will clear the storage directory.",
