@@ -10,11 +10,11 @@ import (
 	"syscall"
 	"time"
 
-	"github.com/containers/common/pkg/resize"
 	"github.com/cri-o/cri-o/internal/log"
 	"github.com/cri-o/cri-o/pkg/config"
 	rspec "github.com/opencontainers/runtime-spec/specs-go"
 	"golang.org/x/net/context"
+	"k8s.io/client-go/tools/remotecommand"
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
@@ -59,7 +59,7 @@ type RuntimeImpl interface {
 	CreateContainer(context.Context, *Container, string, bool) error
 	StartContainer(context.Context, *Container) error
 	ExecContainer(context.Context, *Container, []string, io.Reader, io.WriteCloser, io.WriteCloser,
-		bool, <-chan resize.TerminalSize) error
+		bool, <-chan remotecommand.TerminalSize) error
 	ExecSyncContainer(context.Context, *Container, []string, int64) (*types.ExecSyncResponse, error)
 	UpdateContainer(context.Context, *Container, *rspec.LinuxResources) error
 	StopContainer(context.Context, *Container, int64) error
@@ -70,7 +70,7 @@ type RuntimeImpl interface {
 	ContainerStats(context.Context, *Container, string) (*types.ContainerStats, error)
 	SignalContainer(context.Context, *Container, syscall.Signal) error
 	AttachContainer(context.Context, *Container, io.Reader, io.WriteCloser, io.WriteCloser,
-		bool, <-chan resize.TerminalSize) error
+		bool, <-chan remotecommand.TerminalSize) error
 	PortForwardContainer(context.Context, *Container, string,
 		int32, io.ReadWriteCloser) error
 	ReopenContainerLog(context.Context, *Container) error
@@ -134,7 +134,7 @@ func (r *Runtime) getRuntimeHandler(handler string) (*config.RuntimeHandler, err
 	return rh, nil
 }
 
-// PrivelegedRuntimeHandler returns a boolean value configured for the
+// PrivilegedWithoutHostDevices returns a boolean value configured for the
 // runtimeHandler indicating if devices on the host are passed/not passed
 // to a container running as privileged.
 func (r *Runtime) PrivilegedWithoutHostDevices(handler string) (bool, error) {
@@ -181,6 +181,17 @@ func (r *Runtime) RuntimeType(runtimeHandler string) (string, error) {
 	return rh.RuntimeType, nil
 }
 
+// RuntimeSupportsIDMap returns whether the runtime of runtimeHandler supports the "runtime features"
+// command, and that the output of that command advertises IDMapped mounts as an option
+func (r *Runtime) RuntimeSupportsIDMap(runtimeHandler string) bool {
+	rh, err := r.getRuntimeHandler(runtimeHandler)
+	if err != nil {
+		return false
+	}
+
+	return rh.RuntimeSupportsIDMap()
+}
+
 func (r *Runtime) newRuntimeImpl(c *Container) (RuntimeImpl, error) {
 	rh, err := r.getRuntimeHandler(c.runtimeHandler)
 	if err != nil {
@@ -250,7 +261,7 @@ func (r *Runtime) StartContainer(ctx context.Context, c *Container) error {
 }
 
 // ExecContainer prepares a streaming endpoint to execute a command in the container.
-func (r *Runtime) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *Runtime) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	ctx, span := log.StartSpan(ctx)
 	defer span.End()
 	impl, err := r.RuntimeImpl(c)
@@ -382,7 +393,7 @@ func (r *Runtime) SignalContainer(ctx context.Context, c *Container, sig syscall
 }
 
 // AttachContainer attaches IO to a running container.
-func (r *Runtime) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *Runtime) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	ctx, span := log.StartSpan(ctx)
 	defer span.End()
 	impl, err := r.RuntimeImpl(c)
