@@ -16,7 +16,6 @@ import (
 
 	metadata "github.com/checkpoint-restore/checkpointctl/lib"
 	"github.com/containernetworking/plugins/pkg/ns"
-	"github.com/containers/common/pkg/resize"
 	conmonconfig "github.com/containers/conmon/runner/config"
 	"github.com/containers/podman/v4/pkg/checkpoint/crutils"
 	"github.com/containers/podman/v4/pkg/criu"
@@ -34,6 +33,7 @@ import (
 	"golang.org/x/net/context"
 	"golang.org/x/sys/unix"
 	kwait "k8s.io/apimachinery/pkg/util/wait"
+	"k8s.io/client-go/tools/remotecommand"
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 	utilexec "k8s.io/utils/exec"
 )
@@ -393,7 +393,7 @@ func parseLog(ctx context.Context, l []byte) (stdout, stderr []byte) {
 }
 
 // ExecContainer prepares a streaming endpoint to execute a command in the container.
-func (r *runtimeOCI) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *runtimeOCI) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	_, span := log.StartSpan(ctx)
 	defer span.End()
 
@@ -830,7 +830,6 @@ func (r *runtimeOCI) StopLoopForContainer(c *Container) {
 			// Set state accordingly.
 			c.state.Finished = time.Now()
 			c.opLock.Unlock()
-			c.SetAsDoneStopping()
 			return
 		}
 	}
@@ -885,7 +884,14 @@ func (r *runtimeOCI) StopLoopForContainer(c *Container) {
 
 	c.state.Finished = time.Now()
 	c.opLock.Unlock()
-	c.SetAsDoneStopping()
+
+	c.stopLock.Lock()
+	for _, watcher := range c.stopWatchers {
+		close(watcher)
+	}
+	c.stopping = false
+	close(c.stopTimeoutChan)
+	c.stopLock.Unlock()
 }
 
 // DeleteContainer deletes a container.
@@ -1101,7 +1107,7 @@ func (r *runtimeOCI) signalContainer(c *Container, sig syscall.Signal, all bool)
 }
 
 // AttachContainer attaches IO to a running container.
-func (r *runtimeOCI) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *runtimeOCI) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	ctx, span := log.StartSpan(ctx)
 	defer span.End()
 	if c.Spoofed() {
@@ -1115,7 +1121,7 @@ func (r *runtimeOCI) AttachContainer(ctx context.Context, c *Container, inputStr
 	}
 	defer controlFile.Close()
 
-	resize.HandleResizing(resizeChan, func(size resize.TerminalSize) {
+	utils.HandleResizing(resizeChan, func(size remotecommand.TerminalSize) {
 		log.Debugf(ctx, "Got a resize event: %+v", size)
 		_, err := fmt.Fprintf(controlFile, "%d %d %d\n", 1, size.Height, size.Width)
 		if err != nil {
@@ -1555,8 +1561,8 @@ func (r *runtimeOCI) RestoreContainer(ctx context.Context, c *Container, cgroupP
 }
 
 func (r *runtimeOCI) checkpointRestoreSupported(runtimePath string) error {
-	if !criu.CheckForCriu(criu.PodCriuVersion) {
-		return fmt.Errorf("checkpoint/restore requires at least CRIU %d", criu.PodCriuVersion)
+	if err := criu.CheckForCriu(criu.PodCriuVersion); err != nil {
+		return fmt.Errorf("check for CRIU %w", err)
 	}
 	if !crutils.CRRuntimeSupportsCheckpointRestore(runtimePath) {
 		return fmt.Errorf("configured runtime does not support checkpoint/restore")
