@@ -16,9 +16,11 @@ import (
 	"github.com/cri-o/cri-o/internal/log"
 	"github.com/cri-o/cri-o/internal/opentelemetry"
 	"github.com/cri-o/cri-o/pkg/config"
+	"github.com/cri-o/cri-o/utils"
 	rspec "github.com/opencontainers/runtime-spec/specs-go"
 	"github.com/sirupsen/logrus"
 	"golang.org/x/net/context"
+	"k8s.io/client-go/tools/remotecommand"
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
 )
 
@@ -168,7 +170,7 @@ func (r *runtimePod) RestoreContainer(
 	return r.oci.RestoreContainer(ctx, c, cgroupParent, mountLabel)
 }
 
-func (r *runtimePod) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *runtimePod) ExecContainer(ctx context.Context, c *Container, cmd []string, stdin io.Reader, stdout, stderr io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	return r.oci.ExecContainer(ctx, c, cmd, stdin, stdout, stderr, tty, resizeChan)
 }
 
@@ -243,19 +245,16 @@ func (r *runtimePod) SignalContainer(ctx context.Context, c *Container, sig sysc
 	return r.oci.SignalContainer(ctx, c, sig)
 }
 
-func (r *runtimePod) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan resize.TerminalSize) error {
+func (r *runtimePod) AttachContainer(ctx context.Context, c *Container, inputStream io.Reader, outputStream, errorStream io.WriteCloser, tty bool, resizeChan <-chan remotecommand.TerminalSize) error {
 	attachSocketPath := filepath.Join(r.serverDir, c.ID(), "attach")
 	libpodResize := make(chan resize.TerminalSize, 1)
-	go func() {
-		var event resize.TerminalSize
-		var libpodEvent resize.TerminalSize
 
-		for event = range resizeChan {
-			libpodEvent.Height = event.Height
-			libpodEvent.Width = event.Width
-			libpodResize <- libpodEvent
-		}
-	}()
+	utils.HandleResizing(resizeChan, func(size remotecommand.TerminalSize) {
+		var libpodEvent resize.TerminalSize
+		libpodEvent.Height = size.Height
+		libpodEvent.Width = size.Width
+		libpodResize <- libpodEvent
+	})
 
 	var (
 		stdin          *conmonClient.In
