@@ -19,8 +19,8 @@ var _ = t.Describe("ContainerCheckpoint", func() {
 		beforeEach()
 		createDummyConfig()
 		mockRuncInLibConfig()
-		if !criu.CheckForCriu(criu.PodCriuVersion) {
-			Skip("CRIU is missing or too old.")
+		if err := criu.CheckForCriu(criu.PodCriuVersion); err != nil {
+			Skip("Check CRIU: " + err.Error())
 		}
 		serverConfig.SetCheckpointRestore(true)
 		setupSUT()
