@@ -5,9 +5,13 @@ import (
 	"encoding/base64"
 	"errors"
 	"fmt"
+	"os"
+	"path/filepath"
 	"strings"
+	"syscall"
 	"time"
 
+	"github.com/containers/image/v5/signature"
 	imageTypes "github.com/containers/image/v5/types"
 	"github.com/cri-o/cri-o/internal/log"
 	"github.com/cri-o/cri-o/internal/storage"
@@ -15,6 +19,7 @@ import (
 	"github.com/cri-o/cri-o/utils"
 	"github.com/docker/distribution/registry/api/errcode"
 	types "k8s.io/cri-api/pkg/apis/runtime/v1"
+	crierrors "k8s.io/cri-api/pkg/errors"
 )
 
 var localRegistryPrefix = "localhost/"
@@ -32,14 +37,18 @@ func (s *Server) PullImage(ctx context.Context, req *types.PullImageRequest) (*t
 	}
 	log.Infof(ctx, "Pulling image: %s", image)
 
-	sandboxCgroup := ""
-	if req.SandboxConfig != nil && req.SandboxConfig.Linux != nil {
-		sandboxCgroup = req.SandboxConfig.Linux.CgroupParent
-	}
-	pullArgs := pullArguments{
-		image:         image,
-		sandboxCgroup: sandboxCgroup,
+	pullArgs := pullArguments{image: image}
+
+	sc := req.SandboxConfig
+	if sc != nil {
+		if sc.Linux != nil {
+			pullArgs.sandboxCgroup = sc.Linux.CgroupParent
+		}
+		if sc.Metadata != nil {
+			pullArgs.namespace = sc.Metadata.Namespace
+		}
 	}
+
 	if req.Auth != nil {
 		username := req.Auth.Username
 		password := req.Auth.Password
@@ -93,6 +102,17 @@ func (s *Server) PullImage(ctx context.Context, req *types.PullImageRequest) (*t
 	}
 
 	if pullOp.err != nil {
+		wrap := func(e error) error { return fmt.Errorf("%v: %w", e, pullOp.err) }
+
+		if errors.Is(pullOp.err, syscall.ECONNREFUSED) {
+			return nil, wrap(crierrors.ErrRegistryUnavailable)
+		}
+
+		var policyErr signature.PolicyRequirementError
+		if errors.As(pullOp.err, &policyErr) {
+			return nil, wrap(crierrors.ErrSignatureValidationFailed)
+		}
+
 		return nil, pullOp.err
 	}
 
@@ -116,6 +136,16 @@ func (s *Server) pullImage(ctx context.Context, pullArgs *pullArguments) (string
 		sourceCtx.DockerAuthConfig = &pullArgs.credentials
 	}
 
+	if pullArgs.namespace != "" {
+		policyPath := filepath.Join(s.config.SignaturePolicyDir, pullArgs.namespace+".json")
+		if _, err := os.Stat(policyPath); err == nil {
+			sourceCtx.SignaturePolicyPath = policyPath
+		} else if !os.IsNotExist(err) {
+			return "", fmt.Errorf("read policy path %s: %w", policyPath, err)
+		}
+	}
+	log.Debugf(ctx, "Using pull policy path for image %s: %s", pullArgs.image, sourceCtx.SignaturePolicyPath)
+
 	decryptConfig, err := getDecryptionKeys(s.config.DecryptionKeysPath)
 	if err != nil {
 		return "", err
